==> razorqt-0.5.1.tar.bz2: razorqt-0.5.1/razorqt-panel/plugin-sensors/translations/sensors_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.0">
<context>
    <name>RazorSensorsConfiguration</name>
    <message>
        <source>Razor Sensors Settings</source>
        <translation>Настройки сенсоров Razor</translation>
    </message>
    <message>
        <source>Common</source>
        <translation>Общий</translation>
    </message>
    <message>
        <source>Update interval (seconds)</source>
        <translation>Интервал обновления (секунды)</translation>
    </message>
    <message>
        <source>Temperature bar width</source>
        <translation>Ширина температурной шкалы</translation>
    </message>
    <message>
        <source>Temperature scale</source>
        <translation>Масштаб температуры</translation>
    </message>
    <message>
        <source>Celsius</source>
        <translation>Цельсия</translation>
    </message>
    <message>
        <source>Fahrenheit</source>
        <translation>Фаренгейт</translation>
    </message>
    <message>
        <source>Blink progress bars when the temperature is too high</source>
        <translation>Мигать индикатором состояния когда температура слишком высока</translation>
    </message>
    <message>
        <source>Warning about high temperature</source>
        <translation>Предупреждать о высокой температуре</translation>
    </message>
    <message>
        <source>Sensors</source>
        <translation>Датчики</translation>
    </message>
    <message>
        <source>Detected chips:</source>
        <translation>Обнаруженые чипы:</translation>
    </message>
    <message>
        <source>Chip features:</source>
        <translation>Возможности чипов:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Включён</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Цвет</translation>
    </message>
</context>
</TS>

==> razorqt-0.5.2.tar.bz2: razorqt-0.5.2/razorqt-panel/plugin-sensors/translations/sensors_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.0">
<context>
    <name>RazorSensorsConfiguration</name>
    <message>
        <source>Razor Sensors Settings</source>
        <translation>Настройки сенсоров</translation>
    </message>
    <message>
        <source>Common</source>
        <translation>Общие</translation>
    </message>
    <message>
        <source>Update interval (seconds)</source>
        <translation>Интервал обновления (сек)</translation>
    </message>
    <message>
        <source>Temperature bar width</source>
        <translation>Ширина температурной шкалы</translation>
    </message>
    <message>
        <source>Temperature scale</source>
        <translation>Масштаб температуры</translation>
    </message>
    <message>
        <source>Celsius</source>
        <translation>Цельсия</translation>
    </message>
    <message>
        <source>Fahrenheit</source>
        <translation>Фаренгейта</translation>
    </message>
    <message>
        <source>Blink progress bars when the temperature is too high</source>
        <translation>Мигать индикатором когда температура слишком высокая</translation>
    </message>
    <message>
        <source>Warning about high temperature</source>
        <translation>Предупреждать о высокой температуре</translation>
    </message>
    <message>
        <source>Sensors</source>
        <translation>Сенсоры</translation>
    </message>
    <message>
        <source>Detected chips:</source>
        <translation>Обнаруженые чипы:</translation>
    </message>
    <message>
        <source>Chip features:</source>
        <translation>Возможности чипа:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Включено</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Цвет</translation>
    </message>
</context>
</TS>
